pub async fn execute(
ctx: &SessionContext,
current_table: &str,
spec: &SqlSpec,
) -> Result<String, ChartError>Expand description
Execute the SQL stage.
For SqlSpec::Single: execute the single statement and register result.
For SqlSpec::Multiple: execute all but last as setup, last becomes result.
Returns the name of the output table registered in the session context.